@@ -96,13 +96,15 @@ class _ConfigBase(object):
             elif config_value.dict_key in config_dict:
                 new_value = config_dict[config_value.dict_key]
             elif field in inline_dict or field.upper() in inline_dict:
-                new_value = inline_dict.get(field) or inline_dict.get(field.upper())
+                new_value = inline_dict.get(field)
+                if new_value is None:
+                    new_value = inline_dict.get(field.upper())
                 if new_value is None:
                     new_value = config_value.default
 
             if new_value is not self._NO_VALUE:
                 try:
-                    setattr(self, field, new_value)
+                    setattr(self, field, str(new_value))
                 except ConfigError as e:
                     self._errors[e.field_name] = str(e)
 
@@ -118,16 +120,15 @@ class Config(_ConfigBase):
     async_mode = _BoolConfigValue("ASYNC_MODE", default=True)
     instrument_django_middleware = _BoolConfigValue("INSTRUMENT_DJANGO_MIDDLEWARE", default=True)
     service_version = _ConfigValue("SERVICE_VERSION")
-    framework_name = _ConfigValue("FRAMEWORK_NAME", default=None)
-    framework_version = _ConfigValue("FRAMEWORK_VERSION", default=None)
+    framework_name = _ConfigValue("FRAMEWORK_NAME", default="")
+    framework_version = _ConfigValue("FRAMEWORK_VERSION", default="")
     instrument = _BoolConfigValue("DISABLE_INSTRUMENTATION", default=True)
     base_dir = _ConfigValue("BASE_DIR", default=None)
     application_name = _ConfigValue("APPLICATION_NAME", default=constants.DEFAULT_APPLICATION_NAME)
     environment = _ConfigValue("ENVIRONMENT", env_key="STACKIFY_ENVIRONMENT_NAME", default=constants.DEFAULT_ENVIRONMENT)
     config_file = _ConfigValue("CONFIG_FILE", default=constants.DEFAULT_CONFIG_FILE)
     multiprocessing = _BoolConfigValue("MULTIPROCESSING", default=constants.DEFAULT_MULTIPROCESSING)
-    rum_enabled = _BoolConfigValue("RUM_ENABLED", env_key="STACKIFY_RUM", default=constants.DEFAULT_RUM_ENABLED)
-    rum_auto_injection = _BoolConfigValue("RUM_AUTO_INJECTION", env_key="STACKIFY_RUM_AUTO_INJECT", default=constants.DEFAULT_RUM_AUTO_INJECTION)
+    rum_enabled = _BoolConfigValue("RUMV2_ENABLED", env_key="RETRACE_RUMV2_ENABLED", default=constants.DEFAULT_RUM_ENABLED)
     socket_url = _ConfigValue("SOCKET_URL", env_key="STACKIFY_TRANSPORT_SOCKET_PATH", default=constants.DEFAULT_TRANSPORT_SOCKET_FILE)
     transport = _ConfigValue("TRANSPORT", default=constants.DEFAULT_TRANSPORT)
     http_endpoint = _ConfigValue(
@@ -141,6 +142,20 @@ class Config(_ConfigBase):
     queue = _BoolConfigValue("QUEUE", default=constants.DEFAULT_QUEUE)
     lambda_handler = _ConfigValue("LAMBDA_HANDLER", default="")
     prefix_enabled = _BoolConfigValue("PREFIX_ENABLED", default=constants.DEFAULT_PREFIX_ENABLED)
+    instrument_all = _BoolConfigValue("INSTRUMENT_ALL", default=constants.DEFAULT_INSTRUMENT_ALL)
+    instrument_all_exclude = _ConfigValue("INSTRUMENT_ALL_EXCLUDE", default="")
+    rum_script_url = _ConfigValue(
+        "RUM_SCRIPT_URL",
+        env_key="RETRACE_RUM_SCRIPT_URL",
+        validators=[RegexValidator("^((((https?|ftps?|gopher|telnet|nntp)://)|(mailto:|news:))(%[0-9A-Fa-f]{2}|[-\(\)_.!~*';/?:@&=+$,A-Za-z0-9])+)([).!';/?:,][\[:blank:|:blank:\]])?$")],
+        default=constants.DEFAULT_RUM_SCRIPT_URL
+    )
+    rum_key = _ConfigValue(
+        "RUM_KEY",
+        env_key="RETRACE_RUM_KEY",
+        validators=[RegexValidator("^[A-Za-z0-9_-]+$")],
+        default=constants.DEFAULT_RUM_KEY
+    )
 
 
 class IncrementalFileHandler(logging.handlers.RotatingFileHandler):
@@ -176,9 +191,6 @@ class IncrementalFileHandler(logging.handlers.RotatingFileHandler):
         if not self.delay:
             self.stream = self._open()
 
-        # Set stackify-python-apm increment log file to chmod 777
-        os.chmod(self.baseFilename, 0o777)
-
     def rotation_filename(self, default_name):
         if not callable(self.namer):
             result = default_name
@@ -196,8 +208,31 @@ class IncrementalFileHandler(logging.handlers.RotatingFileHandler):
 
         logging.handlers.RotatingFileHandler.emit(self, record)
 
+    def _open(self):
+        ret = super(IncrementalFileHandler, self)._open()
+
+        # set log file to mod 777
         os.chmod(self.baseFilename, 0o777)
 
+        self._delete_old_files()
+
+        return ret
+
+    def _delete_old_files(self):
+        dir_name = os.path.dirname(self.baseFilename)
+        try:
+            log_files = sorted([
+                os.path.join(dir_name, file)
+                for file in os.listdir(dir_name)
+                if file.endswith('.log')
+            ], key=lambda f: os.stat(f).st_mtime)[::-1]
+
+            if len(log_files) > constants.MAX_LOG_FILE_COUNT:
+                for file in log_files[constants.MAX_LOG_FILE_COUNT:]:
+                    os.path.exists(file) and os.remove(file)
+        except Exception:
+            pass
+
 
 class StackifyFormatter(logging.Formatter):
     """
@@ -213,6 +248,8 @@ def setup_logging(client):
     """
     Configure debug loggings for Stackify APM
     """
+    debug_path = constants.PREFIX_DEBUG_PATH if client.config.prefix_enabled else constants.DEBUG_PATH
+
     try:
         for logger_name in ["stackifyapm", "stackifyapm.traces", "stackifyapm.errors", "stackifyapm.instrument"]:
             _logger = logging.getLogger(logger_name)
@@ -220,8 +257,8 @@ def setup_logging(client):
             _logger.setLevel(logging.DEBUG if client.config.debug else logging.INFO)
             _logger_name = "{}.{}".format(logger_name, "error" in logger_name and "err" or "out")
 
-            if os.path.exists(constants.LOG_PATH):
-                _handler = logging.FileHandler("{}{}".format(constants.LOG_PATH, _logger_name))
+            if os.path.exists(debug_path):
+                _handler = logging.FileHandler("{}{}".format(debug_path, _logger_name))
             else:
                 _handler = logging.StreamHandler()
 
@@ -235,14 +272,16 @@ def setup_stackifyapm_logging(client):
     """
     Configure loggings to pipe to Stackify Linux Agent
     """
+    log_path = constants.PREFIX_LOG_PATH if client.config.prefix_enabled else client.config.log_path
+
     logger = None
     host_name = client.get_system_info().get("hostname")
     process_id = client.get_process_info().get("pid")
-    filename = "{}{}#{}-1.log".format(client.config.log_path, host_name, process_id)
+    filename = "{}{}#{}-1.log".format(log_path, host_name, process_id)
 
     def namer(name):
         num = int(name.split("/")[-1].split(".")[-1] or 0) + 1
-        return "{}{}#{}-{}.log".format(client.config.log_path, host_name, process_id, num)
+        return "{}{}#{}-{}.log".format(log_path, host_name, process_id, num)
 
     try:
         handler = IncrementalFileHandler(filename, maxBytes=50000000)
@@ -255,10 +294,7 @@ def setup_stackifyapm_logging(client):
         logger.setLevel(logging.DEBUG)
         logger.addHandler(handler)
 
-        # Set stackify-python-apm first log file to chmod 777
-        os.chmod(filename, 0o777)
-
     except Exception:
-        print("No such file or directory: {}.".format(client.config.log_path))
+        print("No such file or directory: {}.".format(log_path))
 
     return logger
